@@ -217,23 +217,10 @@ impl Groups {
     pub async fn get_all_group_members(
         &self,
         group_id: &str,
-        page_number: i64,
     ) -> Result<Vec<crate::types::UserCreateResponse>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        if page_number > 0 {
-            query_args.push(format!("page_number={}", page_number));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
         let url = format!(
-            "/groups/{}/members?{}",
+            "/groups/{}/members",
             crate::progenitor_support::encode_path(&group_id.to_string()),
-            query
         );
 
         let mut resp: crate::types::GroupMembersResponseData =
@@ -397,7 +384,7 @@ impl Groups {
      *  \* `security` — View the account's security settings. For example, password requirements for user login or two-factor authentication.<br>
      *  \* `meeting_security` — View the account's meeting security settings.
      */
-    pub async fn get_group_settings_crate_types_domains(
+    pub async fn get_group_settings_domains(
         &self,
         group_id: &str,
         custom_query_fields: &str,
@@ -443,7 +430,7 @@ impl Groups {
      *  \* `security` — View the account's security settings. For example, password requirements for user login or two-factor authentication.<br>
      *  \* `meeting_security` — View the account's meeting security settings.
      */
-    pub async fn get_group_settings_crate_types_meeting_security(
+    pub async fn get_group_settings_meeting_security(
         &self,
         group_id: &str,
         custom_query_fields: &str,
@@ -489,7 +476,7 @@ impl Groups {
      *  \* `security` — View the account's security settings. For example, password requirements for user login or two-factor authentication.<br>
      *  \* `meeting_security` — View the account's meeting security settings.
      */
-    pub async fn get_group_settings_crate_types_response(
+    pub async fn get_group_settings_response(
         &self,
         group_id: &str,
         custom_query_fields: &str,
@@ -628,7 +615,7 @@ impl Groups {
      * * `group_id: &str` -- User's first name.
      * * `option: &str` -- Specify `meeting_security` as the value of this field if you would like to view security settings applied on a meeting hosted by the users in this group.
      */
-    pub async fn get_group_lock_settings_crate_types_meeting_security(
+    pub async fn get_group_lock_settings_meeting_security(
         &self,
         group_id: &str,
         custom_query_fields: &str,
@@ -674,7 +661,7 @@ impl Groups {
      * * `group_id: &str` -- User's first name.
      * * `option: &str` -- Specify `meeting_security` as the value of this field if you would like to view security settings applied on a meeting hosted by the users in this group.
      */
-    pub async fn get_group_lock_settings_crate_types_response(
+    pub async fn get_group_lock_settings_response(
         &self,
         group_id: &str,
         custom_query_fields: &str,
